.. :changelog:

History
-------

0.3.0 (2017-11-24)
++++++++++++++++++

* Added RangeBasedDateHierarchyListFilter.

0.2.0 (2017-10-21)
++++++++++++++++++

* Option to provide custom drill down for any level in the hierarchy.


0.1.0 (2017-09-21)
++++++++++++++++++

* First release on PyPI.
